==> haskell-murmur-hash-0.1.0.9-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: murmur-hash
version: 0.1.0.9
id: murmur-hash-0.1.0.9-Ce2PF3vuSih2JvgNjQCn0O
key: murmur-hash-0.1.0.9-Ce2PF3vuSih2JvgNjQCn0O
license: BSD-3-Clause
maintainer: Thomas Schilling <nominolo@googlemail.com>
author: Thomas Schilling
stability: provisional
homepage: http://github.com/nominolo/murmur-hash
synopsis: MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.
    .
    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.
category: Data, Digest
abi: 5f8503e0d2a6f65d8ac1612a7f83f505
exposed: True
exposed-modules:
    Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs: /usr/lib/ghc-8.4.3/site-local/murmur-hash-0.1.0.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/murmur-hash-0.1.0.9
hs-libraries: HSmurmur-hash-0.1.0.9-Ce2PF3vuSih2JvgNjQCn0O
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html: /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-murmur-hash-0.1.0.9-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: murmur-hash
version: 0.1.0.9
id: murmur-hash-0.1.0.9-Kkx0xWM1TQW2JLiUDrOVZW
key: murmur-hash-0.1.0.9-Kkx0xWM1TQW2JLiUDrOVZW
license: BSD-3-Clause
maintainer: Thomas Schilling <nominolo@googlemail.com>
author: Thomas Schilling
stability: provisional
homepage: http://github.com/nominolo/murmur-hash
synopsis: MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.
    .
    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.
category: Data, Digest
abi: 0e55f861e93dfd11a1f7443460ffe93f
exposed: True
exposed-modules:
    Data.Digest.Murmur32 Data.Digest.Murmur64
import-dirs: /usr/lib/ghc-8.6.1/site-local/murmur-hash-0.1.0.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/murmur-hash-0.1.0.9
hs-libraries: HSmurmur-hash-0.1.0.9-Kkx0xWM1TQW2JLiUDrOVZW
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html: /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
